==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Top/language/lang-polish.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_CATEGORY","Kategoria");
define("_LVOTES","Gosw");
define("_HITS","Odson");
define("_TOPWELCOME","Witaj na stronie TOP w");
define("_READSTORIES","najczciej czytanych artykuw");
define("_COMMENTEDSTORIES","najczciej komentowanych artykuw");
define("_ACTIVECAT","najbardziej aktywnych kategorii");
define("_READSECTION","najczciej czytanych artykuw w sekcji specjalnej");
define("_NEWSSUBMITTERS","najbardziej aktywnych dostarczycieli newsw");
define("_NEWSSENT","wysanych newsw");
define("_VOTEDPOLLS","ankiet w ktrych gosowano najczciej");
define("_MOSTACTIVEAUTHORS","najaktywniejszych autorw");
define("_NEWSPUBLISHED","opublikowanych newsw");
define("_READREVIEWS","najczciej czytanych recenzji");
define("_DOWNLOADEDFILES","najczciej ciganych plikw");
define("_MOSTREADPAGES","Najczciej czytane strony");
define("_MOSTVOTEDSTORIES","most voted stories");
define("_POINTS","points");
define("_BESTRATEDSTORIES","best rated stories (based on 5 maximun points)");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Top/language/lang-polish.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_CATEGORY","Kategoria");
define("_LVOTES","Gosw");
define("_HITS","Odson");
define("_TOPWELCOME","Witaj na stronie TOP w");
define("_READSTORIES","najczciej czytanych artykuw");
define("_COMMENTEDSTORIES","najczciej komentowanych artykuw");
define("_ACTIVECAT","najbardziej aktywnych kategorii");
define("_READSECTION","najczciej czytanych artykuw w sekcji specjalnej");
define("_NEWSSUBMITTERS","najbardziej aktywnych dostarczycieli newsw");
define("_NEWSSENT","wysanych newsw");
define("_VOTEDPOLLS","ankiet w ktrych gosowano najczciej");
define("_MOSTACTIVEAUTHORS","najaktywniejszych autorw");
define("_NEWSPUBLISHED","opublikowanych newsw");
define("_READREVIEWS","najczciej czytanych recenzji");
define("_DOWNLOADEDFILES","najczciej ciganych plikw");
define("_MOSTREADPAGES","Najczciej czytane strony");
define("_MOSTVOTEDSTORIES","most voted stories");
define("_POINTS","points");
define("_BESTRATEDSTORIES","best rated stories (based on 5 maximun points)");

?>
